@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::NoTabsTests;
 # ABSTRACT: (DEPRECATED) Release tests making sure hard tabs aren't used
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::Test::NoTabs';
@@ -10,7 +10,7 @@ use namespace::autoclean;
 
 before register_component => sub {
     warnings::warnif('deprecated',
-        "!!! [MungeFile::WithData] is deprecated and will be removed in a future release; replace it with [MungeFile::WithDataSection]\n",
+        "!!! [NoTabsTests] is deprecated and will be removed in a future release; replace it with [Test::NoTabs]\n",
     );
 };
 
@@ -32,7 +32,7 @@ Dist::Zilla::Plugin::NoTabsTests - (DEPRECATED) Release tests making sure hard t
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
