@@ -1,9 +1,9 @@
-package Dist::Zilla::Plugin::Test::NoTabs; # git description: v0.13-19-gbebd27c
+package Dist::Zilla::Plugin::Test::NoTabs; # git description: v0.14-9-g96d3b3c
 # ABSTRACT: Author tests that ensure hard tabs are not used
 # KEYWORDS: plugin test testing author development whitespace tab tabstop indent formatting
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Moose;
 use Path::Tiny;
@@ -209,7 +209,7 @@ Dist::Zilla::Plugin::Test::NoTabs - Author tests that ensure hard tabs are not u
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -281,12 +281,22 @@ This software is copyright (c) 2010 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge
+=for stopwords Karen Etheridge Noel Maddy
+
+=over 4
+
+=item *
 
 Karen Etheridge <ether@cpan.org>
 
+=item *
+
+Noel Maddy <zhtwnpanta@gmail.com>
+
+=back
+
 =cut
 
 __DATA__
